Processor.App.Extractor.dummy\_extractor
========================================

.. automodule:: Processor.App.Extractor.dummy_extractor

   
   
   

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :toctree:
   
      Extractor
   
   

   
   
   



